@@ -3,7 +3,7 @@ package Event::io;
 use vars qw(@ISA @EXPORT_OK @ATTRIBUTE);
 @ISA = qw(Event::Watcher Exporter);
 @EXPORT_OK = qw(R W E T);  # bit constants
-@ATTRIBUTE = qw(poll fd timeout);
+@ATTRIBUTE = qw(poll fd timeout timeout_cb);
 
 'Event::Watcher'->register;
 
